spannertools.find_spanner_component_starting_at_exactly_score_offset
====================================================================

.. autofunction:: abjad.tools.spannertools.find_spanner_component_starting_at_exactly_score_offset.find_spanner_component_starting_at_exactly_score_offset
